pub fn calculate_duration_segments(
start: Timestamp,
end: Timestamp,
) -> Vec<(Timestamp, Duration)>Expand description
Calculate duration segments for IB historical data request.
This is used to break down a large time range into multiple requests to comply with IB’s duration limits for specific bar sizes.